#
# spec file for package translator
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           translator
Version:        1.4.1
Release:        1.24
Summary:        Translation program
License:        GPL-3.0-or-later
Group:          Productivity/Office/Dictionary
URL:            https://rapidfingers.github.io/Translator
Source:         https://github.com/RapidFingers/Translator/archive/%{version}.tar.gz#/Translator-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.28
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(granite) >= 5.2.3
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
Recommends:     %{name}-lang

%description
This is a translator. It is suited only for small messages, not
big text. Google Translate is used as a backend.

%lang_package

%prep
%setup -q -n Translator-%{version}

cp debian/copyright COPYING

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.rapidfingers.translator GTK Office Dictionary
%find_lang com.github.rapidfingers.translator %{name}.lang
%fdupes %{buildroot}%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
touch $PWD/dir.lst
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%license COPYING
%doc README.md
%{_bindir}/com.github.rapidfingers.translator
%{_datadir}/applications/com.github.rapidfingers.translator.desktop
%{_datadir}/glib-2.0/schemas/com.github.rapidfingers.translator.gschema.xml
%{_datadir}/icons/hicolor/*/apps/com.github.rapidfingers.translator.??g
%{_datadir}/metainfo/com.github.rapidfingers.translator.appdata.xml

%files lang -f %{name}.lang

%changelog
* Mon Apr  1 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.1:
  * Translations to brazilian portuguese (thanks to korndorfer)
  * Fix appdata translations (thanks to NathanBnm)
  * Save theme settings (thanks to camellan)
  * Fix dark theme color
* Mon Mar 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.4.0:
  * Clear button (thanks to camellan)
  * Copy button (thanks to camellan)
  * More languages and translations (thanks to camellan)
  * Bug fixes (thanks to camellan)
* Mon Jan 28 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.2:
  * Switch to meson
- Add HiDPI icons
- Remove obsolete macros
- Spec file cleanup
* Sat Apr  7 2018 avvissu@yandex.by
- Update to 1.2.1:
  * Timeout before translate
  * Fix useless translate on language combobox click
  * Fixed lack of translation, when text is changed during the
    transfer
* Sat Mar 17 2018 avvissu@yandex.by
- Update to 1.2.0:
  * Merge pull request #37 from
    mkinitcpio/#35-Ugly_selected_text_highlight
  * Fix #24 Fix #13
  * Remove space
  * Fix text selection style
* Fri Feb 16 2018 avvissu@yandex.by
- Update to 1.1.0:
  * Removed custom icons
  * Homepage fix
  * Site fix
  * Update README.md
  * Set theme jekyll-theme-cayman
  * Fix app data
  * Fix dark theme
  * Slovak lang; Refactor GlobalSettings
* Sat Jan 20 2018 avvissu@yandex.by
- Update to 1.0.6:
  * Fix AppStream info
  * Fix icon
  * Serbian language; Better desktop info
  * Merge pull request #27 from cassidyjames/patch-1
  * Merge pull request #25 from rankovic/master
- Add README.md
* Tue Dec 26 2017 jengelh@inai.de
- Compact filler wording from description.
* Fri Nov 10 2017 avvissu@yandex.by
- Update to 1.0.3:
  * New language select
  * More languages
  * Fix control file
- Switch from bzr to git
- Add COPYING and AppData files
- Spec file cleanup
* Fri Mar  4 2016 and.november@opensuse.org
- initial package (version 0.7) for openSUSE
